// WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

#include "py.Windows.Phone.Speech.Recognition.h"

namespace py::cpp::Windows::Phone::Speech::Recognition
{
    // ----- Windows.Phone.Speech.Recognition Initialization --------------------

    PyDoc_STRVAR(module_doc, "Windows.Phone.Speech.Recognition");

    static PyModuleDef module_def = {
        PyModuleDef_HEAD_INIT,
        "_winrt_windows_phone_speech_recognition",
        module_doc,
        0,
        nullptr,
        nullptr,
        nullptr,
        nullptr,
        nullptr};
} // py::cpp::Windows::Phone::Speech::Recognition

PyMODINIT_FUNC PyInit__winrt_windows_phone_speech_recognition(void) noexcept
{
    using namespace py::cpp::Windows::Phone::Speech::Recognition;

    if (py::import_winrt_runtime() == -1)
    {
        return nullptr;
    }

    py::pyobj_handle module{PyModule_Create(&module_def)};

    if (!module)
    {
        return nullptr;
    }

    auto object_type = py::get_object_type();
    if (!object_type)
    {
        return nullptr;
    }

    py::pyobj_handle object_bases{PyTuple_Pack(1, object_type)};

    if (!object_bases)
    {
        return nullptr;
    }


    return module.detach();
}
