# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import enum

import winrt.system
from winrt import _winrt_windows_phone_speech_recognition

__all__ = [
    "SpeechRecognitionUIStatus",
]

class SpeechRecognitionUIStatus(enum.IntEnum):
    SUCCEEDED = 0
    BUSY = 1
    CANCELLED = 2
    PREEMPTED = 3
    PRIVACY_POLICY_DECLINED = 4

